﻿using System;
using System.Collections.Generic;
using System.Data.OleDb;

using DevExpress.Utils;
using DevExpress.XtraEditors;
using DevExpress.XtraGrid.Views.Base;
using DevExpress.XtraGrid.Views.Grid;
using DevExpress.XtraPrinting;

namespace TestProject
{
    /// <summary>
    /// 메인 폼
    /// </summary>
    public partial class MainForm : XtraForm
    {
        //////////////////////////////////////////////////////////////////////////////////////////////////// Field
        ////////////////////////////////////////////////////////////////////////////////////////// Private

        #region Field

        /// <summary>
        /// 연결
        /// </summary>
        private OleDbConnection connection;

        /// <summary>
        /// 소스 리스트
        /// </summary>
        private List<OrderDetail> sourceList;

        #endregion

        //////////////////////////////////////////////////////////////////////////////////////////////////// Constructor
        ////////////////////////////////////////////////////////////////////////////////////////// Public

        #region 생성자 - MainForm()

        /// <summary>
        /// 생성자
        /// </summary>
        public MainForm()
        {
            InitializeComponent();

            this.connection = new OleDbConnection("Provider=Microsoft.Jet.OLEDB.4.0;Data Source=nwind.mdb");

            this.gridView.InitializeView
            (
                true,                           // Multi Select
                GridMultiSelectMode.CellSelect, // Grid Multi Select Mode
                DrawFocusRectStyle.CellFocus,   // Draw Focus Rect Style
                true,                           // Show Indicator
                true,                           // Show Column Headers
                true,                           // Allow Column Moving
                true,                           // Allow Column Resizing
                true,                           // Allow Filter
                true,                           // Allow Sort
                false,                          // Allow Cell Merge
                EditorShowMode.Default,         // Editor Show Mode
                false                           // Editable
            );

            this.gridView.OptionsBehavior.AutoPopulateColumns = true;

            this.sourceList = OrderDetail.GetOrderDetailList(this.connection); 

            this.gridControl.DataSource = this.sourceList;

            this.gridView.BestFitColumns();

            this.gridView.PrintInitialize += gridView_PrintInitialize;
            this.previewButton.Click      += previewButton_Click;
        }

        #endregion

        //////////////////////////////////////////////////////////////////////////////////////////////////// Method
        ////////////////////////////////////////////////////////////////////////////////////////// Private

        #region 그리드 뷰 인쇄 초기화하기 - gridView_PrintInitialize(sender, e)

        /// <summary>
        /// 그리드 뷰 인쇄 초기화하기
        /// </summary>
        /// <param name="sender">이벤트 발생자</param>
        /// <param name="e">이벤트 인자</param>
        private void gridView_PrintInitialize(object sender, PrintInitializeEventArgs e)
        {
            PrintingSystemBase printingSystemBase = e.PrintingSystem as PrintingSystemBase;

            printingSystemBase.PageSettings.Landscape = true;
        }

        #endregion
        #region 인쇄 미리보기 버튼 클릭시 처리하기 - previewButton_Click(sender, e)

        /// <summary>
        /// 인쇄 미리보기 버튼 클릭시 처리하기
        /// </summary>
        /// <param name="sender">이벤트 발생자</param>
        /// <param name="e">이벤트 인자</param>
        private void previewButton_Click(object sender, EventArgs e)
        {
            this.gridView.ShowPrintPreview();
        }

        #endregion
    }
}